@@ -37,6 +37,7 @@ major-mode, minor-mode, and global keys are ignored."
   `(let ((ergoemacs-mode t)
          (ergoemacs-unbind-keys t)
          (ergoemacs-shortcut-keys t)
+         (ergoemacs-no-shortcut-keys nil)
          ergoemacs-modal
          ergoemacs-read-input-keys
          (minor-mode-map-alist
@@ -44,7 +45,9 @@ major-mode, minor-mode, and global keys are ignored."
             (ergoemacs-unbind-keys ,@ergoemacs-unbind-keymap)))
          (ergoemacs-emulation-mode-map-alist '())
          (ergoemacs-shortcut-emulation-mode-map-alist
-          `((ergoemacs-shortcut-keys ,@ergoemacs-shortcut-keymap)))
+          `())
+         (ergoemacs-no-shortcut-emulation-mode-map-alist
+          `((ergoemacs-no-shortcut-keys ,@ergoemacs-no-shortcut-keymap)))
          (old-global-map (current-global-map))
          (old-local-map (current-local-map))
          (new-local-map (make-sparse-keymap))
@@ -64,6 +67,7 @@ The global map is ignored, but major/minor modes keymaps are included."
   `(let (ergoemacs-mode
          ergoemacs-unbind-keys
          ergoemacs-shortcut-keys
+         ergoemacs-no-shortcut-keys
          ergoemacs-modal
          ergoemacs-read-input-keys
          (old-global-map (current-global-map))
@@ -230,7 +234,7 @@ Uses `ergoemacs-theme-component--parse-keys-and-body' and
     (setq kb (ergoemacs-theme-component--parse-keys-and-body keys-and-body  nil t)
           plist (nth 0 kb)
           body (nth 1 kb))
-    `(let ((old-ergoemacs-theme ergoemacs-theme)
+    `(let ((old-ergoemacs-theme (or ergoemacs-theme "standard"))
            (old-version (ergoemacs-theme-get-version))
            (macro
             ,(if (plist-get plist ':macro)
@@ -384,17 +388,6 @@ DIFFERENCES are the differences from the layout based on the functions.  These a
        'eieio-object-set-name-string)
       (t 'object-set-name-string)) ,obj ,name))
 
-;;;###autoload
-(defmacro ergoemacs-pushnew (x place &rest plist)
-  "Fix byte-compile errors for emacs versions less than 24.3.
-It says that `adjoin' from `cl' may be called at runtime, so use
-`add-to-list' instead of `pushnew'"
-  (cond
-   ((and (<= 24 emacs-major-version)
-         (<= 3 emacs-minor-version))
-    `(pushnew ,x ,place ,@plist))
-   (t `(add-to-list ',place ,x ,(plist-get plist ':test)))))
-
 ;;;###autoload
 (defmacro ergoemacs-save-buffer-state (&rest body)
   "Eval BODY,
@@ -439,3 +432,6 @@ This was stole/modified from `c-save-buffer-state'"
 (provide 'ergoemacs-macros)
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;; ergoemacs-macros.el ends here
+;; Local Variables:
+;; coding: utf-8-emacs
+;; End:
