@@ -8,7 +8,7 @@
 ;; Maintainer: Matthew L. Fidler <matthew.fidler@gmail.com>
 ;; Created: August 01 2007
 ;; Keywords: convenience
-;; Version: 5.14.7.1
+;; Version: 5.14.7.2
 ;; Package-Requires: ((emacs "24.1") (undo-tree "0.6.5"))
 ;; URL: https://github.com/ergoemacs/ergoemacs-mode
 
@@ -74,11 +74,13 @@
 (defvar ergoemacs-debug-buffer " *ErgoEmacs-mode Debug Log*"
   "Variable for ergoemacs debugging buffer.")
 
+(defvar ergoemacs-debug-keymap--temp-map nil)
 (defun ergoemacs-debug-keymap (keymap)
   "Print keymap bindings."
   (if (not (ignore-errors (symbolp (symbol-name keymap))))
-      (let ((temp-map keymap))
-        (ergoemacs-debug "%s" (substitute-command-keys "\\{temp-map}")))
+      (progn
+        (setq ergoemacs-debug-keymap--temp-map keymap)
+        (ergoemacs-debug "%s" (substitute-command-keys "\\{ergoemacs-debug-keymap--temp-map}")))
     (ergoemacs-debug-heading "%s"
                              (format "Keymap Description: %s" (symbol-name keymap)))
     (ergoemacs-debug "%s" (substitute-command-keys (format "\\{%s}" (symbol-name keymap))))))
@@ -91,7 +93,7 @@
   (ergoemacs-debug (concat "** "
                            (condition-case err
                                (apply 'format arg)
-                             (eurror (format "Bad format string: %s" arg)))))
+                             (error (format "Bad format string: %s (%s)" arg err)))))
   (ergoemacs-debug "Time Since Start ergoemacs-mode: %1f sec" (- (float-time) ergoemacs-debug-heading-start-time))
   (ergoemacs-debug "Time Since Last Heading: %1f sec" (- (float-time) ergoemacs-debug-heading-last-time))
   (setq ergoemacs-debug-heading-last-time (float-time)))
@@ -112,7 +114,7 @@
                   ergoemacs-debug
                   (condition-case err
                       (apply 'format arg)
-                    (error (format "Bad Format String: %s" arg)))))))
+                    (error (format "Bad Format String: %s (%s)" arg err)))))))
 
 (defun ergoemacs-debug-clear ()
   "Clears the variable `ergoemacs-debug' and `ergoemacs-debug-buffer'"
@@ -146,7 +148,7 @@
   (load "ergoemacs-layouts"))
 
 ;; Ergoemacs-keybindings version
-(defconst ergoemacs-mode-version "5.14.7.1"
+(defconst ergoemacs-mode-version "5.14.7.2"
   "Ergoemacs-keybindings minor mode version number.")
 
 (defconst ergoemacs-mode-changes "Delete window Alt+0 changed to Alt+2.
@@ -236,6 +238,7 @@ Valid values are:
 (defvar ergoemacs-curr-prefix-arg nil)
 (defvar ergoemacs-repeat-keys nil)
 (defvar ergoemacs-shortcut-keys nil)
+(defvar ergoemacs-no-shortcut-keys nil)
 (defvar ergoemacs-unbind-keys nil)
 (defvar ergoemacs-read-input-keys nil)
 
@@ -261,6 +264,9 @@ Valid values are:
 (defvar ergoemacs-shortcut-keymap (make-sparse-keymap)
   "ErgoEmacs minor mode shortcut keymap")
 
+(defvar ergoemacs-no-shortcut-keymap (make-sparse-keymap)
+  "ErgoEmacs minor mode shortcut-free keymap")
+
 (defvar ergoemacs-read-input-keymap (make-sparse-keymap)
   "Ergoemacs minor mode shortcut input keymap.")
 
@@ -289,7 +295,7 @@ Valid values are:
                     (if (not (eq 'ergoemacs-mode (nth 0 x)))
                         x
                       `(ergoemacs-mode ,(concat
-                                         (if (not ergoemacs-theme)
+                                         (if (string= "standard" (or ergoemacs-theme "standard"))
                                              " ErgoEmacs"
                                            (concat " Ergo"
                                                    (upcase (substring ergoemacs-theme 0 1))
@@ -309,7 +315,7 @@ Valid values are:
   "Setups keys based on a particular layout. Based on `ergoemacs-keyboard-layout'."
   (interactive)
   (ergoemacs-debug "Ergoemacs layout: %s" ergoemacs-keyboard-layout)
-  (ergoemacs-debug "Ergoemacs theme: %s" ergoemacs-theme)
+  (ergoemacs-debug "Ergoemacs theme: %s" (or ergoemacs-theme "standard"))
   (ergoemacs-debug "Emacs Version: %s" (emacs-version))
   (let ((ergoemacs-state (if (boundp 'ergoemacs-mode) ergoemacs-mode nil))
         (layout
@@ -363,6 +369,9 @@ Valid values are:
 (defvar ergoemacs-shortcut-emulation-mode-map-alist nil
   "Override keys in `ergoemacs-mode' for `emulation-mode-map-alist'")
 
+(defvar ergoemacs-no-shortcut-emulation-mode-map-alist nil
+  "Override keys in `ergoemacs-mode' for `emulation-mode-map-alist'")
+
 (defun ergoemacs-emulations (&optional remove)
   "Add ergoemacs emulations to `emulation-mode-map-alist'.
 When REMOVE is true, remove the emulations."
@@ -370,7 +379,8 @@ When REMOVE is true, remove the emulations."
                            ergoemacs-read-emulation-mode-map-alist
                            ergoemacs-repeat-emulation-mode-map-alist
                            ergoemacs-emulation-mode-map-alist
-                           ergoemacs-shortcut-emulation-mode-map-alist)))
+                           ergoemacs-shortcut-emulation-mode-map-alist
+                           ergoemacs-no-shortcut-emulation-mode-map-alist)))
     (funcall (if remove #'remove-hook #'add-hook) 'emulation-mode-map-alists hook)))
 
 (defvar ns-alternate-modifier)
@@ -415,8 +425,8 @@ bindings the keymap is:
   ;; This will possibly allow swapping of C-c and M-c.
   (if ergoemacs-mode
       (progn
-        (setq ergoemacs-debug-heading-start-time (float-time))
-        (setq ergoemacs-debug-heading-last-time (float-time))
+        (setq ergoemacs-debug-heading-start-time (float-time)
+              ergoemacs-debug-heading-last-time (float-time))
         (ergoemacs-debug "* Ergoemacs-mode is turning ON.")
         (when cua-mode
           (cua-mode -1)
@@ -426,8 +436,8 @@ bindings the keymap is:
         ;;   (setq ergoemacs-org-CUA-compatible org-CUA-compatible))
         (ergoemacs-emulations)
         ;; Setup keys
-        (setq ergoemacs-shortcut-keymap (make-sparse-keymap))
-        (ergoemacs-setup-keys t)
+        (setq ergoemacs-shortcut-keymap (make-sparse-keymap)
+              ergoemacs-no-shortcut-keymap (make-sparse-keymap))
         (ergoemacs-debug-heading "Ergoemacs Keys have loaded.")
         (when (and ergoemacs-use-mac-command-as-meta
                    (eq system-type 'darwin))
@@ -441,14 +451,6 @@ bindings the keymap is:
             (when am
               (setq ergoemacs-old-ns-alternate-modifier (symbol-value am))
               (set am nil))))
-        ;; Turn on menu
-        (if ergoemacs-use-menus
-            (progn
-              (require 'ergoemacs-menus)
-              (ergoemacs-menus-on))
-          (when (featurep 'ergoemacs-menus)
-            (ergoemacs-menus-off)))
-        (ergoemacs-debug-heading "Ergoemacs Menus have loaded.")
         (when (ergoemacs-real-key-binding [ergoemacs-single-command-keys])
           (if (not ergoemacs-read-key-overriding-overlay-save)
               (setq overriding-terminal-local-map ergoemacs-read-key-overriding-terminal-local-save)
@@ -457,6 +459,15 @@ bindings the keymap is:
         ;; Fix `substitute-command-keys'
         (ergoemacs-enable-c-advices)
         (setq ergoemacs-unbind-keys t)
+        (ergoemacs-setup-keys t)
+        ;; Turn on menu
+        (if ergoemacs-use-menus
+            (progn
+              (require 'ergoemacs-menus)
+              (ergoemacs-menus-on))
+          (when (featurep 'ergoemacs-menus)
+            (ergoemacs-menus-off)))
+        (ergoemacs-debug-heading "Ergoemacs Menus have loaded.")
         (add-hook 'pre-command-hook 'ergoemacs-pre-command-hook)
         (ergoemacs-populate-pre-command-hook)
         (ergoemacs-debug-heading "Ergoemacs-mode turned ON."))
@@ -648,6 +659,8 @@ This is done by checking if this is a command that supports shift selection or c
     ergoemacs-shortcut-movement
     ergoemacs-read-key
     ergoemacs-modal-default
+    ergoemacs-modal-movement
+    ergoemacs-modal-movement-no-shift-select
     ergoemacs-read-key-default))
 
 (defun ergoemacs-smart-function-p (var)
@@ -672,40 +685,37 @@ This is done by checking if this is a command that supports shift selection or c
     (when transient-mark-mode ;; restore transient-mark-mode state
       (setq transient-mark-mode ergoemacs-mark-active)))
   (let (deactivate-mark)
-    (condition-case err
-        (progn
-          (ergoemacs-restore-post-command-hook)
-          (when (and ergoemacs-repeat-keys
-                     (keymapp ergoemacs-repeat-keymap)
-                     (not (lookup-key ergoemacs-repeat-keymap (this-single-command-keys))))
-            (setq ergoemacs-repeat-keys nil)
-            (ergoemacs-mode-line))
-          (when (and (not ergoemacs-read-input-keys)
-                     (not unread-command-events))
-            (setq ergoemacs-read-input-keys t)
-            (when (ergoemacs-real-key-binding [ergoemacs-single-command-keys])
-              (if (not ergoemacs-read-key-overriding-overlay-save)
-                  (setq overriding-terminal-local-map ergoemacs-read-key-overriding-terminal-local-save)
-                (delete-overlay ergoemacs-read-key-overriding-overlay-save)
-                (setq ergoemacs-read-key-overriding-overlay-save nil))))
-          (setq ergoemacs-this-command this-command)
-          (when ergoemacs-mode
-            ;; Raise shortcuts and modal modes.
-            (ergoemacs-shuffle-keys)
-            (let ((ergoemacs-real-key-binding
-                   (read-kbd-macro
-                    (format
-                     "<override> %s" (key-description (this-single-command-keys))))))
-              (cond
-               ((condition-case err
-                    (interactive-form ergoemacs-real-key-binding)
-                  (error nil))
-                (setq this-command ergoemacs-real-key-binding))))
-            ;; Used to check for `saved-overriding-map', but changed
-            ;; in emacs 24.4, and `ergoemacs-mode' deals with
-            ;; universal functions independent of emacs...
-            (ergoemacs-install-shortcuts-up)))
-      (error nil)))
+    (ignore-errors
+      (progn
+        (ergoemacs-restore-post-command-hook)
+        (when (and ergoemacs-repeat-keys
+                   (keymapp ergoemacs-repeat-keymap)
+                   (not (lookup-key ergoemacs-repeat-keymap (this-single-command-keys))))
+          (setq ergoemacs-repeat-keys nil)
+          (ergoemacs-mode-line))
+        (when (and (not ergoemacs-read-input-keys)
+                   (not unread-command-events))
+          (setq ergoemacs-read-input-keys t)
+          (when (ergoemacs-real-key-binding [ergoemacs-single-command-keys])
+            (if (not ergoemacs-read-key-overriding-overlay-save)
+                (setq overriding-terminal-local-map ergoemacs-read-key-overriding-terminal-local-save)
+              (delete-overlay ergoemacs-read-key-overriding-overlay-save)
+              (setq ergoemacs-read-key-overriding-overlay-save nil))))
+        (setq ergoemacs-this-command this-command)
+        (when ergoemacs-mode
+          ;; Raise shortcuts and modal modes.
+          (ergoemacs-shuffle-keys)
+          (let ((ergoemacs-real-key-binding
+                 (read-kbd-macro
+                  (format
+                   "<override> %s" (key-description (this-single-command-keys))))))
+            (cond
+             ((commandp ergoemacs-real-key-binding t)
+              (setq this-command ergoemacs-real-key-binding))))
+          ;; Used to check for `saved-overriding-map', but changed
+          ;; in emacs 24.4, and `ergoemacs-mode' deals with
+          ;; universal functions independent of emacs...
+          (ergoemacs-install-shortcuts-up)))))
   (unless (ergoemacs-smart-function-p this-command)
     (run-hooks 'ergoemacs-pre-command-hook))
   t)
@@ -716,10 +726,9 @@ This is done by checking if this is a command that supports shift selection or c
   "Ergoemacs post-command-hook"
   (when ergoemacs-read-input-keys
     (if (and mark-active deactivate-mark
-               (or (ergoemacs-is-movement-command-p this-command)
-                   (condition-case err
-                       (string-match "\\<mark\\>" (symbol-name this-command))
-                     (error nil))))
+             (or (ergoemacs-is-movement-command-p this-command)
+                 (ignore-errors
+                   (string-match "\\<mark\\>" (symbol-name this-command)))))
         (progn
           (setq deactivate-mark nil))))
   (let (deactivate-mark)
@@ -736,6 +745,7 @@ This is done by checking if this is a command that supports shift selection or c
         (progn
           (when ergoemacs-mode
             (setq ergoemacs-shortcut-keys t)
+            (setq ergoemacs-no-shortcut-keys nil)
             (ergoemacs-shuffle-keys)
             (when (not unread-command-events)
               (ergoemacs-install-shortcuts-up)))
@@ -757,7 +767,7 @@ This is done by checking if this is a command that supports shift selection or c
   t)
 
 (provide 'ergoemacs-mode)
-
+;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;; ergoemacs-mode.el ends here
 ;; Local Variables:
 ;; coding: utf-8-emacs
