@@ -43,17 +43,138 @@
 
 (ergoemacs-theme-component standard-vars ()
   "Enabled/changed variables/modes"
-  (setq org-CUA-compatible t
+  (setq ergoemacs-alt-text (replace-regexp-in-string "[Qq]" "" (ergoemacs-pretty-key "M-q"))
+        ergoemacs-ctl-text (replace-regexp-in-string "[Qq]" "" (ergoemacs-pretty-key "C-q"))
+        ergoemacs-alt-ctl-text (replace-regexp-in-string "[Qq]" "" (ergoemacs-pretty-key "M-C-q"))
+        org-CUA-compatible t
         org-support-shift-select t
         set-mark-command-repeat-pop t
         org-special-ctrl-a/e t
         ido-vertical-define-keys 'C-n-C-p-up-down-left-right
-        scroll-error-top-bottom t)
+        scroll-error-top-bottom t
+        initial-scratch-message (substitute-command-keys ";; This buffer is for notes you don't want to save, and for Lisp evaluation.\n;; If you want to create a file, visit that file with \\[find-file],\n;; then enter the text in that file's own buffer.")
+        ;; Remove tutorial and guided tour, since the keys don't apply...
+        fancy-startup-text
+        `((:face (variable-pitch font-lock-comment-face)
+                 "Welcome to "
+                 :link ("GNU Emacs"
+                        ,(lambda (_button) (browse-url "http://www.gnu.org/software/emacs/"))
+                        "Browse http://www.gnu.org/software/emacs/")
+                 ", one component of the "
+                 :link
+                 ,(lambda ()
+                    (if (eq system-type 'gnu/linux)
+                        `("GNU/Linux"
+                          ,(lambda (_button) (browse-url "http://www.gnu.org/gnu/linux-and-gnu.html"))
+                          "Browse http://www.gnu.org/gnu/linux-and-gnu.html")
+                      `("GNU" ,(lambda (_button) (describe-gnu-project))
+                        "Display info on the GNU project")))
+                 " operating system.\n\n"
+                 "\n"
+                 ;; :link ("Emacs Guided Tour"
+                 ;;        ,(lambda (_button)
+                 ;;           (browse-url "http://www.gnu.org/software/emacs/tour/"))
+                 ;;        "Browse http://www.gnu.org/software/emacs/tour/")
+                 ;; "\tOverview of Emacs features at gnu.org\n"
+                 :link ("View Emacs Manual" ,(lambda (_button) (info-emacs-manual)))
+                 "\tView the Emacs manual using Info\n"
+                 :link ("Absence of Warranty" ,(lambda (_button) (describe-no-warranty)))
+                 "\tGNU Emacs comes with "
+                 :face (variable-pitch (:slant oblique))
+                 "ABSOLUTELY NO WARRANTY\n"
+                 :face variable-pitch
+                 :link ("Copying Conditions" ,(lambda (_button) (describe-copying)))
+                 "\tConditions for redistributing and changing Emacs\n"
+                 :link ("Ordering Manuals" ,(lambda (_button) (view-order-manuals)))
+                 "\tPurchasing printed copies of manuals\n"
+                 "\n"))
+        ;;
+        fancy-about-text
+        `((:face (variable-pitch font-lock-comment-face)
+                 "This is "
+                 :link ("GNU Emacs"
+                        ,(lambda (_button) (browse-url "http://www.gnu.org/software/emacs/"))
+                        "Browse http://www.gnu.org/software/emacs/")
+                 ", one component of the "
+                 :link
+                 ,(lambda ()
+                    (if (eq system-type 'gnu/linux)
+                        `("GNU/Linux"
+                          ,(lambda (_button)
+                             (browse-url "http://www.gnu.org/gnu/linux-and-gnu.html"))
+                          "Browse http://www.gnu.org/gnu/linux-and-gnu.html")
+                      `("GNU" ,(lambda (_button) (describe-gnu-project))
+                        "Display info on the GNU project.")))
+                 " operating system.\n"
+                 :face (variable-pitch font-lock-builtin-face)
+                 "\n"
+                 ,(lambda () (emacs-version))
+                 "\n"
+                 :face (variable-pitch (:height 0.8))
+                 ,(lambda () emacs-copyright)
+                 "\n\n"
+                 :face variable-pitch
+                 :link ("Authors"
+                        ,(lambda (_button)
+                           (view-file (expand-file-name "AUTHORS" data-directory))
+                           (goto-char (point-min))))
+                 "\tMany people have contributed code included in GNU Emacs\n"
+                 :link ("Contributing"
+                        ,(lambda (_button)
+                           (view-file (expand-file-name "CONTRIBUTE" data-directory))
+                           (goto-char (point-min))))
+                 "\tHow to contribute improvements to Emacs\n"
+                 "\n"
+                 :link ("GNU and Freedom" ,(lambda (_button) (describe-gnu-project)))
+                 "\tWhy we developed GNU Emacs, and the GNU operating system\n"
+                 :link ("Absence of Warranty" ,(lambda (_button) (describe-no-warranty)))
+                 "\tGNU Emacs comes with "
+                 :face (variable-pitch (:slant oblique))
+                 "ABSOLUTELY NO WARRANTY\n"
+                 :face variable-pitch
+                 :link ("Copying Conditions" ,(lambda (_button) (describe-copying)))
+                 "\tConditions for redistributing and changing Emacs\n"
+                 :link ("Getting New Versions" ,(lambda (_button) (describe-distribution)))
+                 "\tHow to obtain the latest version of Emacs\n"
+                 :link ("Ordering Manuals" ,(lambda (_button) (view-order-manuals)))
+                 "\tBuying printed manuals from the FSF\n"
+                 "\n"
+                 ;; :link ("Emacs Guided Tour"
+                 ;;        ,(lambda (_button)
+                 ;;           (browse-url "http://www.gnu.org/software/emacs/tour/"))
+                 ;;        "Browse http://www.gnu.org/software/emacs/tour/")
+                 ;; "\tSee an overview of Emacs features at gnu.org"
+		 ))
+        )
   (add-hook 'kill-buffer-hook 'ergoemacs-save-buffer-to-recently-closed)
   (undo-tree-mode 1)
   (shift-select-mode t)
   (delete-selection-mode 1)
-  (setq recentf-menu-before "Close")
+  (setq recentf-menu-before "Close"
+        recentf-menu-items-for-commands
+        (list
+         ["Open Last Closed"
+          ergoemacs-open-last-closed
+          :help "Remove duplicates, and obsoletes files from the recent list"
+          :keys (ergoemacs-shortcut-for-command 'ergoemacs-open-last-closed)
+          :active t]
+         ["Cleanup list"
+          recentf-cleanup
+          :help "Remove duplicates, and obsoletes files from the recent list"
+          :active t]
+         ["Edit list..."
+          recentf-edit-list
+          :help "Manually remove files from the recent list"
+          :active t]
+         ["Save list now"
+          recentf-save-list
+          :help "Save the list of recently opened files now"
+          :active t]
+         ["Options..."
+          (customize-group "recentf")
+          :help "Customize recently opened files menu and options"
+          :active t]
+         ))
   (recentf-mode 1)
   ;; (setq cua--rectangle-modifier-key ergoemacs-cua-rect-modifier)
   ;; (setq cua--rectangle-keymap (make-sparse-keymap))
@@ -158,7 +279,7 @@
 
   ;; Ergoemacs fixed keys...
   
-  (global-set-key (kbd "<M-f4>") 'delete-frame) ;; Alt+f4 should work.
+  (global-set-key (kbd "<M-f4>") 'ergoemacs-delete-frame) ;; Alt+f4 should work.
   
    ; Alt+→
   (global-set-key (kbd "<M-up>") 'ergoemacs-backward-block) ; Alt+↑
@@ -486,10 +607,20 @@
   (define-key eshell-mode-map (kbd "M-h") 'eshell-bol)
   (define-key comint-mode-map (kbd "M-H") 'comint-bol))
 
+(ergoemacs-theme-component move-and-transpose-lines ()
+  "Move Current line/selection down or up with Alt+up or Alt+down"
+  (global-set-key [\M-up] 'ergoemacs-move-text-up)
+  (global-set-key [\M-down] 'ergoemacs-move-text-down))
+
 (ergoemacs-theme-component move-page ()
   "Move by Page"
   (global-unset-key (kbd "M-v"))
   (global-unset-key (kbd "C-v"))
+  (global-unset-key (kbd "C-M-v"))
+  ;; Not sure I like the scroll other window placment... C+M+ argh.
+  (global-set-key (kbd "C-M-I") 'scroll-other-window-down)
+  (global-set-key (kbd "C-M-K") 'scroll-other-window)
+  ;; These are OK
   (global-set-key (kbd "M-I") '(scroll-down-command scroll-down))
   (global-set-key (kbd "M-K") '(scroll-up-command scroll-up)))
 
@@ -666,7 +797,6 @@
 (ergoemacs-theme-component quit ()
   "Escape exits"
   (global-set-key (kbd "<escape>") 'keyboard-quit)
-  (define-key browse-kill-ring-mode-map (kbd "<escape>") 'browse-kill-ring-quit)
   (when isearch-mode-hook
     :modify-map t
     :full-shortcut-keymap t
@@ -902,7 +1032,9 @@
     (global-set-key [remap describe-key]
                     'ergoemacs-describe-key)
     (global-set-key [remap describe-mode]
-                    'ergoemacs-describe-major-mode)))
+                    'ergoemacs-describe-major-mode)
+    (global-set-key [remap ergoemacs-print-buffer-confirm]
+                    'pr-interface)))
 
 (ergoemacs-theme-component ergoemacs-banish-shift ()
   "Banish Shift Combinations with <apps> SPC"
@@ -1009,7 +1141,7 @@
                   ("Function Keys" (fn-keys f2-edit))
                   ("Remaps" (ido-remaps helm-remaps multiple-cursors-remaps))
                   ("Extreme ErgoEmacs" (guru no-backspace ergoemacs-banish-shift))
-                  ("Standard Keys" (standard-fixed fixed-bold-italic quit))
+                  ("Standard Keys" (standard-fixed fixed-bold-italic quit move-and-transpose-lines))
                   ("Keys during Key Sequence" (f2-edit apps-swap backspace-del-seq))))
 
 (ergoemacs-theme reduction ()
@@ -1050,7 +1182,7 @@
                  apps-swap
                  save-options-on-exit)
   :optional-off '(guru no-backspace search-reg
-                       ergoemacs-banish-shift)
+                       ergoemacs-banish-shift move-and-transpose-lines)
   :options-menu '(("Menu/Apps Key" (apps apps-apps apps-punctuation))
                   ("Function Keys" (fn-keys f2-edit))
                   ("Remaps" (ido-remaps helm-remaps multiple-cursors-remaps))
